==> kwave_0.7.2.orig.tar.gz: kwave-0.7.2/libkwave/SampleFIFO.h <==
/*************************************************************************
           SampleFIFO.h  -  simple FIFO, tuned for sample_t
                             -------------------
    begin                : Sun Apr 11 2004
    copyright            : (C) 2004 by Thomas Eschenbacher
    email                : Thomas.Eschenbacher@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _SAMPLE_FIFO_H_
#define _SAMPLE_FIFO_H_

#include "config.h"
#include <qmemarray.h>
#include "libkwave/Sample.h"

class SampleFIFO
{
public:
    /**
     * Constructor
     *
     * @param size initial number of samples the FIFO can hold
     */
    SampleFIFO(unsigned int size = 0);

    /** Destructor */
    virtual ~SampleFIFO();

    /**
     * Set the size of the FIFO. This destroys the content and sets
     * all pointers to their initial value.
     *
     * @param size new depth of the FIFO in samples
     */
    virtual void resize(unsigned int size);

    /**
     * puts samples into the FIFO
     *
     * @param source reference to an array of samples to feed in
     * @return true if successful, false on overruns
     */
    virtual bool put(const QMemArray<sample_t> &source);

    /**
     * Align/shift the data in the FIFO so that the current read
     * position is at the start of the internal buffer.
     */
    virtual void align();

    /**
     * Returns the number of samples that can be read out.
     * @see m_written
     */
    virtual unsigned int length();

    /**
     * Returns a reference to the internal buffer. Normally called
     * after "align" to forward the internal buffer to a SampleWriter
     * or similar.
     */
    virtual QMemArray<sample_t> &data();

private:

    /** size of the FIFO in samples */
    unsigned int m_size;

    /** buffer for the sample data */
    QMemArray<sample_t> m_buffer;

    /** number of written samples [0...m_size-1] */
    unsigned int m_written;

    /**
     * index of the write position, where the next sample would
     * be written.
     */
    unsigned int m_write_pos;

};

#endif /* _SAMPLE_FIFO_H_ */

==> kwave-0.7.11-1.tar.gz: kwave-0.7.11/libkwave/SampleFIFO.h <==
/*************************************************************************
           SampleFIFO.h  -  simple FIFO, tuned for sample_t
                             -------------------
    begin                : Sun Apr 11 2004
    copyright            : (C) 2004 by Thomas Eschenbacher
    email                : Thomas.Eschenbacher@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _SAMPLE_FIFO_H_
#define _SAMPLE_FIFO_H_

#include "config.h"
#include <qvaluevector.h>
#include <qmutex.h>
#include "libkwave/KwaveSampleArray.h"

class SampleFIFO
{
public:
    /** Constructor */
    SampleFIFO();

    /** Destructor */
    virtual ~SampleFIFO();

    /**
     * Reset the FIFO. This destroys the content and sets
     * all pointers to their initial value.
     */
     virtual void flush();

    /**
     * puts samples into the FIFO
     *
     * @param buffer reference to an array of samples to feed in
     */
    virtual void put(const Kwave::SampleArray &source);

    /**
     * gets and removes samples from the FIFO
     *
     * @param buffer reference to an array of samples to be filled
     * @return number of received samples
     */
    virtual unsigned int get(Kwave::SampleArray &buffer);

    /**
     * Returns the number of samples that can be read out.
     * @see m_written
     */
    virtual unsigned int length();

private:

    /** list of buffers with sample data */
    QValueVector<Kwave::SampleArray> m_buffer;

    /**
     * number of samples that have already been read out
     * from the first buffer (head, first one to read out)
     */
    unsigned int m_read_offset;

    /** mutex for access to the FIFO (recursive) */
    QMutex m_lock;

};

#endif /* _SAMPLE_FIFO_H_ */
